@@ -20,13 +20,21 @@ class AuthKeysPlugin(FirmwarePlugin):
             auth_keys = forms.CharField(required=False, help_text='Enter the SSH '
                 'keys allowed to log in as root (in "authorized_keys" format). '
                 'You may leave the default keys to allow centralized management '
-                'of your node.',
+                'of your node. '
+                'Please note that this may expose your node to an attack '
+                'if the testbed registry is compromised.',
             widget=forms.Textarea(
                 attrs={'cols': 125, 'rows': 10, 'style': 'font-family:%s' % MONOSPACE_FONTS}))
             
             def __init__(self, *args, **kwargs):
                 super(AuthKeysForm, self).__init__(*args, **kwargs)
-                if keys_path:
+                # load stored authentication keys (#383)
+                assert hasattr(self.node, 'keys'), "The node doesn't have keys, have you runned firmware migrations?"
+                if self.node.keys.ssh_auth:
+                    self.fields['auth_keys'].initial = self.node.keys.ssh_auth
+                    self.fields['auth_keys'].help_text += (' <span style="color:red">'
+                        'Loaded stored keys as initial value.</span>')
+                elif keys_path:
                     self.fields['auth_keys'].initial = open(keys_path).read()
             
             def clean_auth_keys(self):
@@ -34,6 +42,9 @@ class AuthKeysPlugin(FirmwarePlugin):
                 for ssh_pubkey in auth_keys.splitlines():
                     if not ssh_pubkey.lstrip().startswith('#'): # ignore comments
                         validate_ssh_pubkey(ssh_pubkey)
+                # store new authentication keys (#383)
+                self.node.keys.ssh_auth = auth_keys
+                self.node.keys.save()
                 return auth_keys
         
         return AuthKeysForm
