@@ -152,7 +152,7 @@ class TicketAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
     change_view_actions = [
         resolve_tickets, close_tickets, reject_tickets, take_tickets
     ]
-    change_form_template = "admin/controller/change_form.html"
+    change_form_template = "admin/issues/ticket/change_form.html"
     form = TicketForm
     readonly_fields = (
         'display_summary', 'display_queue', 'display_group', 'display_owner',
@@ -307,6 +307,11 @@ class TicketAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
     
     def change_view(self, request, object_id, form_url='', extra_context=None):
         """ Change view actions based on ticket state """
+        # Check object_id is a valid pk (simplification of ModelAdmin.get_object)
+        try:
+            int(object_id)
+        except ValueError:
+            object_id = None
         ticket = get_object_or_404(Ticket, pk=object_id)
         # Change view actions based on ticket state
         self.change_view_actions = filter_actions(self, ticket, request)
@@ -321,7 +326,10 @@ class TicketAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
                 content += request.POST[u'messages-2-0-content']
                 request.POST[u'messages-2-0-content'] = content
         ticket.mark_as_read_by(request.user)
-        context = {'title': "Issue #%i - %s" % (ticket.id, ticket.subject)}
+        context = {
+            'title': "Issue #%i - %s" % (ticket.id, ticket.subject),
+            'short_title': "Issue #%i" % ticket.id
+        }
         context.update(extra_context or {})
         return super(TicketAdmin, self).change_view(
             request, object_id, form_url, extra_context=context)
