@@ -27,6 +27,8 @@ class Host(models.Model):
             help_text='Free-form textual description of this host.')
     owner = models.ForeignKey(get_user_model(), related_name='tinc_hosts',
             help_text='The user who administrates this host (its creator by default)')
+    island = models.ForeignKey('nodes.Island', null=True, blank=True,
+            help_text='An optional island used to hint where this tinc client reaches to.')
     related_tincclient = generic.GenericRelation('tinc.TincClient')
     
     def __unicode__(self):
@@ -133,7 +135,7 @@ class TincServer(TincHost):
     def __unicode__(self):
         if self.content_type.model == 'server':
             return 'server'
-        return "%s_%s" % (self.content_type.model, self.object_id)
+        return u'%s_%s' % (self.content_type.model, self.object_id)
     
     def clean(self):
         # TODO prevent changes when is_active = true, but take into account that 
@@ -175,24 +177,6 @@ class TincServer(TincHost):
         return '\n'.join(host)
 
 
-class Island(models.Model):
-    """
-    Describes a network island (i.e. a disconnected part of a community network)
-    where the testbed is reachable from. A testbed is reachable from an island
-    when there is a gateway that gives access to the testbed server (possibly
-    through other gateways), or when the server itself is in that island.
-    """
-    name = models.CharField(max_length=32, unique=True,
-            help_text='The unique name of this island. A single line of free-form '
-                      'text with no whitespace surrounding it.',
-            validators=[validate_name])
-    description = models.TextField(blank=True,
-            help_text='Optional free-form textual description of this island.')
-    
-    def __unicode__(self):
-        return self.name
-
-
 class TincAddress(models.Model):
     """
     Describes an IP Address of a Tinc Server.
@@ -202,7 +186,7 @@ class TincAddress(models.Model):
             validators=[OrValidator([validators.validate_ipv4_address, validate_host_name])])
     port = models.SmallIntegerField(default=settings.TINC_PORT_DFLT,
             help_text='TCP/UDP port of this tinc address.')
-    island = models.ForeignKey(Island, null=True, blank=True,
+    island = models.ForeignKey('nodes.Island', null=True, blank=True,
             help_text='<a href="http://wiki.confine-project.eu/arch:rest-api#island_'
                       'at_server">Island</a> this tinc address is reachable from.')
     server = models.ForeignKey(TincServer, related_name='addresses')
@@ -231,8 +215,6 @@ class TincClient(TincHost):
     Describes a Tinc Client in the testbed. A tinc client can be a testbed node
     or a host.
     """
-    island = models.ForeignKey(Island, null=True, blank=True,
-            help_text='An optional island used to hint where this tinc client reaches to.')
     content_type = models.ForeignKey(ContentType)
     object_id = models.PositiveIntegerField()
     
@@ -242,7 +224,7 @@ class TincClient(TincHost):
         unique_together = ('content_type', 'object_id')
     
     def __unicode__(self):
-        return "%s_%s" % (self.content_type.model, self.object_id)
+        return u'%s_%s' % (self.content_type.model, self.object_id)
     
     @property
     def address(self):
@@ -284,8 +266,9 @@ class TincClient(TincHost):
         config = ["Name = %s" % self.name]
         for server in self.connect_to.all():
             line = "ConnectTo = %s" % server.name
-            has_island = server.addresses.filter(island=self.island).exists()
-            if self.island and has_island:
+            tinc_island = self.content_object.island
+            has_island = server.addresses.filter(island=tinc_island).exists()
+            if tinc_island and has_island:
                 config.insert(0, line)
             else:
                 config.append(line)
