@@ -3,6 +3,8 @@ from __future__ import absolute_import
 import json
 import six
 
+from django.db.models import Q
+
 from api import serializers
 
 from . import settings
@@ -78,8 +80,9 @@ class NodeCreateSerializer(serializers.UriHyperlinkedModelSerializer):
             msg = " Check if you have group or node administrator roles at the provided group."
             fields['group'].error_messages['does_not_exist'] += msg
             # bug #321: filter by user.id (None for Anonymous users)
-            fields['group'].queryset = queryset.filter(allow_nodes=True,
-                                        roles__user=user.id, roles__is_group_admin=True)
+            fields['group'].queryset = queryset.filter(
+                Q(roles__is_group_admin=True) | Q(roles__is_node_admin=True),
+                allow_nodes=True, roles__user=user.id)
         return fields
 
 class NodeSerializer(NodeCreateSerializer):
