@@ -25,8 +25,8 @@ class ResourceReqSerializer(serializers.ModelSerializer):
 
 
 for producer_model in ResourcePlugin.get_producers_models():
-    api.aggregate(producer_model, ResourceSerializer, name='resources')
+    api.aggregate(producer_model, ResourceSerializer, name='resources', required=False)
 
 
 for consumer_model in ResourcePlugin.get_consumers_models():
-    api.aggregate(consumer_model, ResourceReqSerializer, name='resources')
+    api.aggregate(consumer_model, ResourceReqSerializer, name='resources', required=False)
