@@ -23,7 +23,7 @@ from .actions import renew_selected_slices, reset_selected, update_selected, cre
 from .filters import MySlicesListFilter, MySliversListFilter, SliverSetStateListFilter
 from .forms import (SliceAdminForm, SliverAdminForm, SliverIfaceInlineForm,
     SliverIfaceInlineFormSet, SliceSliversForm)
-from .helpers import wrap_action, remove_slice_id, state_value
+from .helpers import wrap_action, remove_slice_id, state_value, get_readonly_file_fields
 from .models import Sliver, SliverProp, SliverIface, Slice, SliceProp, Template
 
 
@@ -39,7 +39,6 @@ STATE_COLORS = {
 
 colored_set_state = colored('set_state', STATE_COLORS, verbose=True, bold=False)
 
-
 def num_slivers(instance):
     """ return num slivers as a link to slivers changelist view """
     num = instance.slivers.count()
@@ -106,19 +105,22 @@ class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
             'fields': ('description', 'template', 'set_state')
         }),
         ('Advanced', {
-            'classes': ('collapse',),
-            'fields': ('exp_data', 'exp_data_sha256', 'overlay', 'overlay_sha256',
+            'classes': ('collapse', 'info'),
+            'description': 'If you want to define a URI, you should remove '
+                           'previously the uploaded file.',
+            'fields': ('exp_data', 'exp_data_uri', 'exp_data_sha256',
+                       'overlay', 'overlay_uri', 'overlay_sha256',
                        'new_instance_sn')
         }),
     )
-    readonly_fields = ['new_instance_sn', 'exp_data_sha256', 'overlay_sha256']
+    readonly_fields = ['new_instance_sn']
     search_fields = ['description', 'node__description', 'node__name', 'slice__name']
     inlines = [SliverPropInline, SliverIfaceInline]
     actions = [update_selected]
     change_view_actions = [update_selected]
     default_changelist_filters = (('my_slivers', 'True'),)
     change_form_template = "admin/controller/change_form.html"
-    form = SliverAdminForm # FIXME: ignored but don't know why! Check inheritance
+    form = SliverAdminForm
     
     class Media:
         css = {
@@ -165,6 +167,10 @@ class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
         request._slice_ = obj.slice
         return super(SliverAdmin, self).get_form(request, obj, **kwargs)
     
+    def get_readonly_fields(self, request, obj=None):
+        readonly_fields = super(SliverAdmin, self).get_readonly_fields(request, obj=obj)
+        return readonly_fields + get_readonly_file_fields(obj)
+    
     def queryset(self, request):
         """ Annotate number of ifaces for future ordering on the changelist """
         qs = super(SliverAdmin, self).queryset(request)
@@ -189,6 +195,8 @@ class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
             formfield = self.formfield_for_foreignkey(db_field, **kwargs)
             kwargs['widget'] = LinkedRelatedFieldWidgetWrapper(formfield.widget,
                     db_field.rel, self.admin_site)
+        elif  '_sha256' in db_field.name or '_uri' in db_field.name:
+            kwargs['widget'] = forms.TextInput(attrs={'size': 80})
         return super(SliverAdmin, self).formfield_for_dbfield(db_field, **kwargs)
     
     def formfield_for_choice_field(self, db_field, request, **kwargs):
@@ -201,6 +209,11 @@ class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
     
     def change_view(self, request, object_id, form_url='', extra_context=None):
         """ Linked title """
+        # Check object_id is a valid pk (simplification of ModelAdmin.get_object)
+        try:
+            int(object_id)
+        except ValueError:
+            object_id = None
         sliver = get_object_or_404(Sliver, pk=object_id)
         slice_link = get_admin_link(sliver.slice)
         node_link = get_admin_link(sliver.node)
@@ -387,7 +400,7 @@ class SliceSliversAdmin(SliverAdmin):
     def change_view(self, request, object_id, slice_id, form_url='', extra_context=None):
         """ Customizations needed for being nested to slices """
         slice = get_object_or_404(Slice, pk=slice_id)
-        sliver = get_object_or_404(Sliver, pk=object_id)
+        sliver = get_object_or_404(Sliver, pk=object_id, slice=slice)
         self.slice_id = slice_id
         self.node_id = sliver.node_id
         context = { 'slice': slice }
@@ -426,7 +439,7 @@ class SliverInline(PermissionTabularInline):
         return instance.interfaces.filter(type='public4').count()
     
     def management(self, instance):
-        return instance.interfaces.filter(type='management').count()
+        return instance.interfaces.filter(type='management').exists()
     management.boolean = True
     
     def isolated(self, instance):
@@ -494,9 +507,16 @@ class SliverNodeInline(SliverInline):
     def has_delete_permission(self, request, obj=None):
         """
         Disallow deleting slivers from node change_view:
-        Why a node admin can be able of doing that?
+        Why a node admin will be able to do that?
         """
         return False
+    
+    def has_change_permission(self, request, obj=None, view=False):
+        # HACK for allow node_admins change a node with slivers
+        # As this Inline is readonly and doesn't allow to introduce
+        # changes, this workaround shouldn't have side effects
+        # See #476
+        return True
 
     def slice_link(self, instance):
         return get_admin_link(instance.slice)
@@ -519,10 +539,7 @@ class SliceAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmi
     ]
     list_display_links = ('name', 'id')
     list_filter = [MySlicesListFilter, 'set_state', 'template']
-    readonly_fields = [
-        'instance_sn', 'new_sliver_instance_sn', 'expires_on', 'exp_data_sha256',
-        'overlay_sha256'
-    ]
+    readonly_fields = ['instance_sn', 'new_sliver_instance_sn', 'expires_on']
     date_hierarchy = 'expires_on'
     search_fields = ['name']
     inlines = [SlicePropInline, SliverInline]
@@ -533,9 +550,12 @@ class SliceAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmi
             'fields': ('name', 'description', 'template', 'set_state','expires_on', 'group'),
         }),
         ('Advanced', {
-            'classes': ('collapse',),
-            'fields': ('exp_data', 'exp_data_sha256', 'overlay', 'overlay_sha256',
-                       'vlan_nr', 'instance_sn', 'new_sliver_instance_sn',
+            'classes': ('collapse', 'info'),
+            'description': 'If you want to define a URI, you should remove '
+                           'previously the uploaded file.',
+            'fields': ('exp_data', 'exp_data_uri', 'exp_data_sha256', 'overlay',
+                       'overlay_uri', 'overlay_sha256', 'vlan_nr', 'instance_sn',
+                       'new_sliver_instance_sn'
             )
         }),
     )
@@ -544,6 +564,12 @@ class SliceAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmi
     change_view_actions = [renew_selected_slices, reset_selected]
     default_changelist_filters = (('my_slices', 'True'),)
     
+    class Media:
+        css = {
+             'all': (
+                'slices/css/warning-form.css',)
+        }
+
     def queryset(self, request):
         """ Annotate number of slivers on the slice for sorting on changelist """
         qs = super(SliceAdmin, self).queryset(request)
@@ -591,16 +617,18 @@ class SliceAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmi
         readonly_fields = super(SliceAdmin, self).get_readonly_fields(request, obj=obj)
         if 'set_state' not in readonly_fields and obj is None:
             return readonly_fields + ['set_state']
-        return readonly_fields
+        return readonly_fields + get_readonly_file_fields(obj)
     
     def formfield_for_dbfield(self, db_field, **kwargs):
         """ Make description input widget smaller """
         if db_field.name == 'description':
             kwargs['widget'] = forms.Textarea(attrs={'cols': 85, 'rows': 5})
-        if db_field.name == 'template':
+        elif db_field.name == 'template':
             formfield = self.formfield_for_foreignkey(db_field, **kwargs)
             kwargs['widget'] = LinkedRelatedFieldWidgetWrapper(formfield.widget,
                 db_field.rel, self.admin_site)
+        elif  '_sha256' in db_field.name or '_uri' in db_field.name:
+            kwargs['widget'] = forms.TextInput(attrs={'size': 80})
         return super(SliceAdmin, self).formfield_for_dbfield(db_field, **kwargs)
 
     def change_view(self, request, object_id, form_url='', extra_context=None):
