@@ -61,7 +61,7 @@ class Reset(APIView):
 def make_upload_file(model, field, field_url):
     # Just for the browsabe API
     attrs = {field: serializers.FileField()}
-    UploadFlieSerializer = type(field+'Serializer', (serializers.Serializer,), attrs)
+    UploadFileSerializer = type(field+'Serializer', (serializers.Serializer,), attrs)
     
     # TODO ApiPermissionsMixin
     class UploadFile(generics.CreateAPIView):
@@ -79,7 +79,7 @@ def make_upload_file(model, field, field_url):
         """ % {'field': field, 'field_url': field_url}
         url_name = 'upload-%s' % field_url
         rel = 'http://confine-project.eu/rel/controller/do-%s' % url_name
-        serializer_class = UploadFlieSerializer
+        serializer_class = UploadFileSerializer
         
         def post(self, request, *args, **kwargs):
             obj = get_object_or_404(model, pk=kwargs.get('pk'))
@@ -159,6 +159,23 @@ class SliceDetail(generics.RetrieveUpdateDestroyAPIView):
         Renew, Reset, make_upload_file(Slice, 'exp_data', 'exp-data'),
         make_upload_file(Slice, 'overlay', 'overlay'),
     ]
+    def put(self, request, *args, **kwargs):
+        """
+        Check that set_state has not changed because has
+        side effects and breaks idempotence (#490)
+        """
+        pk = kwargs.get('pk', None)
+        try:
+            slice = Slice.objects.get(pk=pk)
+        except Slice.DoesNotExist:
+            pass
+        else:
+            new_set_state = request.DATA.get('set_state', None)
+            if new_set_state and slice.set_state != new_set_state:
+                msg = {'set_state': ["Not allowed to change using a PUT operation. "
+                                     "PATCH should be used instead."]}
+                return Response(data=msg, status=400)
+        return super(SliceDetail, self).put(request, *args, **kwargs)
 
 
 class SliverList(ApiPermissionsMixin, generics.URIListCreateAPIView):
