@@ -1,5 +1,6 @@
 from django import forms
 from django.contrib.admin.templatetags.admin_list import _boolean_icon
+from django.core.exceptions import ValidationError
 
 from controller.forms.widgets import ShowText
 from nodes.models import Node
@@ -37,7 +38,7 @@ class SliceAdminForm(forms.ModelForm):
                 else:
                     self.fields['vlan_nr'].widget = ShowText()
                     self.fields['vlan_nr'].widget.attrs['readonly'] = True
-        
+    
     def clean_vlan_nr(self):
         """ Return -1 if user requests vlan_nr """
         vlan_nr = self.cleaned_data['vlan_nr']
@@ -46,24 +47,62 @@ class SliceAdminForm(forms.ModelForm):
             return None if not vlan_nr else -1
         # ! Register state: return the old value
         return self.initial["vlan_nr"]
+    
+    def clean(self):
+        """Clean _uri when uploading a file"""
+        cleaned_data = super(SliceAdminForm, self).clean()
+        for field_name in ('exp_data', 'overlay'):
+            if cleaned_data.get(field_name):
+                cleaned_data[field_name + "_uri"] = ''
+        return cleaned_data
+
 
 class SliverAdminForm(forms.ModelForm):
+    """
+    Used when sliver showed directly (slice independent)
+    e.g. /admin/sliver/1
+    """
     def __init__(self, *args, **kwargs):
-        """ Improve user interface: form style and empty labels """
-        # FIXME: Works but is NOT called: see SliverAdmin at admin.py
         super(SliverAdminForm, self).__init__(*args, **kwargs)
+        # warn visually on sliver state override by slice state
         if self.instance:
             sliver_state = state_value(self.instance.set_state)
             slice_state = state_value(self.instance.slice.set_state)
-            if sliver_state > slice_state:
+            if sliver_state > slice_state and 'set_state' in self.fields:
                 self.fields['set_state'].widget.attrs = {'class': 'warning'}
+    
+    def clean(self):
+        """Clean _uri when uploading a file"""
+        cleaned_data = super(SliverAdminForm, self).clean()
+        for field_name in ('exp_data', 'overlay'):
+            if cleaned_data.get(field_name):
+                cleaned_data[field_name + "_uri"] = ''
+        return cleaned_data
 
 
 class SliceSliversForm(forms.ModelForm):
+    """
+    Used when sliver showed via its slice (url nested)
+    e.g. /admin/slice/1/sliver/1
+    """
     def __init__(self, *args, **kwargs):
         super(SliceSliversForm, self).__init__(*args, **kwargs)
         self.instance.node = self.node
         self.instance.slice = self.slice
+        # warn visually on sliver state override by slice state
+        if self.instance:
+            sliver_state = state_value(self.instance.set_state)
+            slice_state = state_value(self.instance.slice.set_state)
+            if sliver_state > slice_state and 'set_state' in self.fields:
+                self.fields['set_state'].widget.attrs = {'class': 'warning'}
+    
+    def clean(self):
+        """Clean _uri when uploading a file"""
+        cleaned_data = super(SliceSliversForm, self).clean()
+        for field_name in ('exp_data', 'overlay'):
+            if cleaned_data.get(field_name):
+                cleaned_data[field_name + "_uri"] = ''
+        return cleaned_data
 
 
 class SliverIfaceInlineFormSet(forms.models.BaseInlineFormSet):
@@ -84,6 +123,18 @@ class SliverIfaceInlineFormSet(forms.models.BaseInlineFormSet):
                 initial_data['interfaces-%d-type' % num] = iface_type
             kwargs['data'] = initial_data
         super(SliverIfaceInlineFormSet, self).__init__(*args, **kwargs)
+    
+    def clean(self):
+        """Check that one interface of type private has been defined."""
+        super(SliverIfaceInlineFormSet, self).clean()
+        priv_ifaces = 0
+        for form in self.forms:
+            if form.cleaned_data.get('type', '') == 'private' and not form.cleaned_data.get('DELETE', False):
+                priv_ifaces += 1
+            if priv_ifaces > 1:
+                raise ValidationError('There can only be one interface of type private.')
+        if priv_ifaces == 0:
+            raise ValidationError('There must exist one interface of type private.')
 
 
 class SliverIfaceInlineForm(forms.ModelForm):
