@@ -17,6 +17,7 @@ class FakeFileField(serializers.CharField):
         self.field_name = kwargs.pop('field')
         super(FakeFileField, self).__init__(*args, **kwargs)
     
+#   TODO validate _uri value when setted directly (i.e. valid file extensions)
 #   TODO remove file object._delete
 #    def from_native(self, value):
     def to_native(self, value):
@@ -50,6 +51,7 @@ class SliverSerializer(serializers.UriHyperlinkedModelSerializer):
     exp_data_uri = FakeFileField(field='exp_data', required=False)
     overlay_uri = FakeFileField(field='overlay', required=False)
     instance_sn = serializers.IntegerField(read_only=True)
+    mgmt_net = serializers.Field()
     
     class Meta:
         model = Sliver
@@ -71,10 +73,16 @@ class SliverSerializer(serializers.UriHyperlinkedModelSerializer):
         return attrs
 
     def validate_interfaces(self, attrs, source):
-        """ Check if first interface is of type private """
+        """Check that one interface of type private has been defined."""
         interfaces = attrs.get(source, [])
-        if 'private' not in [iface.type for iface in interfaces]:
-           raise serializers.ValidationError('At least one private interface is required.')
+        priv_ifaces = 0
+        for iface in interfaces:
+            if iface.type == 'private':
+                priv_ifaces += 1
+            if priv_ifaces > 1:
+                raise serializers.ValidationError('There can only be one interface of type private.')
+        if priv_ifaces == 0:
+            raise serializers.ValidationError('There must exist one interface of type private.')
         return attrs
 
 
@@ -82,6 +90,7 @@ class SliverDetailSerializer(SliverSerializer):
     class Meta:
         model = Sliver
         read_only_fields = ('node', 'slice')
+        exclude = ('exp_data', 'overlay')
 
 
 class SliceCreateSerializer(serializers.UriHyperlinkedModelSerializer):
